Error class

This is returned when a parameter is not valid.

It can contain additional warnings. The sealed base class ist the Result. The other Result ist a Success. when the function executed correctly.

Inheritance

Constructors

Error({required String message, required List<String> warnings})
This requires the error message and the warnings.

Properties

hashCode int
The hash code for this object.
no setterinherited
message String
The error message.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
warnings List<String>
A list of warnings.
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited