Error class
This is returned when a parameter is not valid.
It can contain additional warnings. The sealed base class ist the Result. The other Result ist a Success. when the function executed correctly.
Constructors
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited